@@ -7,6 +7,9 @@ use warnings;
 # Modules.
 use Error::Pure::Always;
 
+# Set env error type.
+$ENV{'ERROR_PURE_TYPE'} = 'Die';
+
 # Error.
 die '1';
 
